@@ -22,7 +22,6 @@
 #define CMPL_VECTOR_H
 
 #include <math.h>
-#include <gsl/gsl_vector_complex_double.h>
 
 #ifdef __cplusplus
 #define complex _Complex
@@ -38,9 +37,6 @@ __BEGIN_DECLS
 
 typedef double complex cmpl;
 
-extern void vec_complex_set (gsl_vector_complex *v, int i, cmpl val);
-extern cmpl vec_complex_get (gsl_vector_complex *v, int i);
-
 __END_DECLS
 
 #endif
