@@ -34,11 +34,14 @@
 #define LUA_INDEX_CONVENTION
 
 #ifdef WIN32
+#ifndef __cplusplus
 #undef bool
 typedef int bool;
 #define false 0
 #define true 1
+#endif
 #else
+/* linux */
 #include <stdbool.h>
 #endif
 
