@@ -23,6 +23,7 @@
 #include <string.h>
 #include <stdio.h>
 #include "lua-utils.h"
+#include "gs-types.h"
 
 char const * const CACHE_FIELD_NAME = "__cache";
 
@@ -46,13 +47,14 @@ mlua_get_property (lua_State *L, const struct luaL_Reg *p, bool use_cache)
   if (! use_cache)
     return p->func (L);
 
-  lua_getfield (L, 1, CACHE_FIELD_NAME);
+  lua_getfenv (L, 1);
+  lua_getfield (L, -1, CACHE_FIELD_NAME);
   if (lua_isnil (L, -1))
     {
       lua_pop (L, 1);
       lua_newtable (L);
       lua_pushvalue (L, -1);
-      lua_setfield (L, 1, CACHE_FIELD_NAME);
+      lua_setfield (L, -3, CACHE_FIELD_NAME);
       cache_is_new = true;
     }
 
@@ -77,8 +79,10 @@ mlua_get_property (lua_State *L, const struct luaL_Reg *p, bool use_cache)
 void
 mlua_null_cache (lua_State *L, int index)
 {
+  lua_getfenv (L, index);
   lua_pushnil (L);
-  lua_setfield (L, index, CACHE_FIELD_NAME);
+  lua_setfield (L, -2, CACHE_FIELD_NAME);
+  lua_pop (L, 1);
 }
 
 int
@@ -104,6 +108,26 @@ mlua_index_with_properties (lua_State *L, const struct luaL_Reg *properties,
   return 1;
 }
 
+int
+mlua_newindex_with_properties (lua_State *L, const struct luaL_Reg *properties)
+{
+  char const * key;
+  const struct luaL_Reg *reg;
+
+  key = lua_tostring (L, 2);
+  if (key == NULL)
+    return 0;
+
+  reg = mlua_find_method (properties, key);
+  if (reg)
+    {
+      lua_remove (L, 2);
+      return reg->func (L);
+    }
+
+  return luaL_error (L, "invalid property for %s object",  full_type_name (L, 1));
+}
+
 void
 mlua_check_field_type (lua_State *L, int index, const char *key, int type,
 		       const char *error_msg)
@@ -165,3 +189,20 @@ mlua_named_string (lua_State *L, int index, const char *key)
   lua_pop (L, 1);
   return r;
 }
+
+void
+mlua_fenv_set (lua_State *L, int index, int fenv_index)
+{
+  lua_getfenv (L, index);
+  lua_insert (L, -2);
+  lua_rawseti (L, -2, fenv_index);
+  lua_pop (L, 1);
+}
+
+void
+mlua_fenv_get (lua_State *L, int index, int fenv_index)
+{
+  lua_getfenv (L, index);
+  lua_rawgeti (L, -1, fenv_index);
+  lua_remove (L, -2);
+}
